@@ -11,7 +11,7 @@ pub struct RegisterBlock {
     pub ns_fw_version: crate::Reg<ns_fw_version::NS_FW_VERSION_SPEC>,
     #[doc = "0x10 - Image key revocation ID (Monotonic counter)"]
     pub image_key_revoke: crate::Reg<image_key_revoke::IMAGE_KEY_REVOKE_SPEC>,
-    _reserved5: [u8; 4usize],
+    _reserved5: [u8; 0x04],
     #[doc = "0x18 - ."]
     pub rotkh_revoke: crate::Reg<rotkh_revoke::ROTKH_REVOKE_SPEC>,
     #[doc = "0x1c - ."]
@@ -24,52 +24,52 @@ pub struct RegisterBlock {
     pub enable_fa_mode: crate::Reg<enable_fa_mode::ENABLE_FA_MODE_SPEC>,
     #[doc = "0x2c - CMPA Page programming on going. This field shall be set to 0x5CC55AA5 in the active CFPA page each time CMPA page programming is going on. It shall always be set to 0x00000000 in the CFPA scratch area."]
     pub cmpa_prog_in_progress: crate::Reg<cmpa_prog_in_progress::CMPA_PROG_IN_PROGRESS_SPEC>,
-    _reserved_11_prince_region0_iv: [u8; 4usize],
-    _reserved_12_prince_region0_iv: [u8; 4usize],
-    _reserved_13_prince_region0_iv: [u8; 4usize],
-    _reserved_14_prince_region0_iv: [u8; 4usize],
-    _reserved_15_prince_region0_iv: [u8; 4usize],
-    _reserved_16_prince_region0_iv: [u8; 4usize],
-    _reserved_17_prince_region0_iv: [u8; 4usize],
-    _reserved_18_prince_region0_iv: [u8; 4usize],
-    _reserved_19_prince_region0_iv: [u8; 4usize],
-    _reserved_20_prince_region0_iv: [u8; 4usize],
-    _reserved_21_prince_region0_iv: [u8; 4usize],
-    _reserved_22_prince_region0_iv: [u8; 4usize],
-    _reserved_23_prince_region0_iv: [u8; 4usize],
-    _reserved_24_prince_region0_iv: [u8; 4usize],
-    _reserved_25_prince_region1_iv: [u8; 4usize],
-    _reserved_26_prince_region1_iv: [u8; 4usize],
-    _reserved_27_prince_region1_iv: [u8; 4usize],
-    _reserved_28_prince_region1_iv: [u8; 4usize],
-    _reserved_29_prince_region1_iv: [u8; 4usize],
-    _reserved_30_prince_region1_iv: [u8; 4usize],
-    _reserved_31_prince_region1_iv: [u8; 4usize],
-    _reserved_32_prince_region1_iv: [u8; 4usize],
-    _reserved_33_prince_region1_iv: [u8; 4usize],
-    _reserved_34_prince_region1_iv: [u8; 4usize],
-    _reserved_35_prince_region1_iv: [u8; 4usize],
-    _reserved_36_prince_region1_iv: [u8; 4usize],
-    _reserved_37_prince_region1_iv: [u8; 4usize],
-    _reserved_38_prince_region1_iv: [u8; 4usize],
-    _reserved_39_prince_region2_iv: [u8; 4usize],
-    _reserved_40_prince_region2_iv: [u8; 4usize],
-    _reserved_41_prince_region2_iv: [u8; 4usize],
-    _reserved_42_prince_region2_iv: [u8; 4usize],
-    _reserved_43_prince_region2_iv: [u8; 4usize],
-    _reserved_44_prince_region2_iv: [u8; 4usize],
-    _reserved_45_prince_region2_iv: [u8; 4usize],
-    _reserved_46_prince_region2_iv: [u8; 4usize],
-    _reserved_47_prince_region2_iv: [u8; 4usize],
-    _reserved_48_prince_region2_iv: [u8; 4usize],
-    _reserved_49_prince_region2_iv: [u8; 4usize],
-    _reserved_50_prince_region2_iv: [u8; 4usize],
-    _reserved_51_prince_region2_iv: [u8; 4usize],
-    _reserved_52_prince_region2_iv: [u8; 4usize],
-    _reserved53: [u8; 40usize],
-    #[doc = "0x100 - Customer Defined (Programable through ROM API)"]
+    _reserved_11_prince_region0_iv: [u8; 0x04],
+    _reserved_12_prince_region0_iv: [u8; 0x04],
+    _reserved_13_prince_region0_iv: [u8; 0x04],
+    _reserved_14_prince_region0_iv: [u8; 0x04],
+    _reserved_15_prince_region0_iv: [u8; 0x04],
+    _reserved_16_prince_region0_iv: [u8; 0x04],
+    _reserved_17_prince_region0_iv: [u8; 0x04],
+    _reserved_18_prince_region0_iv: [u8; 0x04],
+    _reserved_19_prince_region0_iv: [u8; 0x04],
+    _reserved_20_prince_region0_iv: [u8; 0x04],
+    _reserved_21_prince_region0_iv: [u8; 0x04],
+    _reserved_22_prince_region0_iv: [u8; 0x04],
+    _reserved_23_prince_region0_iv: [u8; 0x04],
+    _reserved_24_prince_region0_iv: [u8; 0x04],
+    _reserved_25_prince_region1_iv: [u8; 0x04],
+    _reserved_26_prince_region1_iv: [u8; 0x04],
+    _reserved_27_prince_region1_iv: [u8; 0x04],
+    _reserved_28_prince_region1_iv: [u8; 0x04],
+    _reserved_29_prince_region1_iv: [u8; 0x04],
+    _reserved_30_prince_region1_iv: [u8; 0x04],
+    _reserved_31_prince_region1_iv: [u8; 0x04],
+    _reserved_32_prince_region1_iv: [u8; 0x04],
+    _reserved_33_prince_region1_iv: [u8; 0x04],
+    _reserved_34_prince_region1_iv: [u8; 0x04],
+    _reserved_35_prince_region1_iv: [u8; 0x04],
+    _reserved_36_prince_region1_iv: [u8; 0x04],
+    _reserved_37_prince_region1_iv: [u8; 0x04],
+    _reserved_38_prince_region1_iv: [u8; 0x04],
+    _reserved_39_prince_region2_iv: [u8; 0x04],
+    _reserved_40_prince_region2_iv: [u8; 0x04],
+    _reserved_41_prince_region2_iv: [u8; 0x04],
+    _reserved_42_prince_region2_iv: [u8; 0x04],
+    _reserved_43_prince_region2_iv: [u8; 0x04],
+    _reserved_44_prince_region2_iv: [u8; 0x04],
+    _reserved_45_prince_region2_iv: [u8; 0x04],
+    _reserved_46_prince_region2_iv: [u8; 0x04],
+    _reserved_47_prince_region2_iv: [u8; 0x04],
+    _reserved_48_prince_region2_iv: [u8; 0x04],
+    _reserved_49_prince_region2_iv: [u8; 0x04],
+    _reserved_50_prince_region2_iv: [u8; 0x04],
+    _reserved_51_prince_region2_iv: [u8; 0x04],
+    _reserved_52_prince_region2_iv: [u8; 0x04],
+    _reserved53: [u8; 0x28],
+    #[doc = "0x100..0x1e0 - Customer Defined (Programable through ROM API)"]
     pub customer_defined: [crate::Reg<customer_defined::CUSTOMER_DEFINED_SPEC>; 56],
-    #[doc = "0x1e0 - SHA256_DIGEST0 for DIGEST\\[31:0\\]
+    #[doc = "0x1e0..0x200 - SHA256_DIGEST0 for DIGEST\\[31:0\\]
 SHA256_DIGEST1 for DIGEST\\[63:32\\]
 SHA256_DIGEST2 for DIGEST\\[95:64\\]
 SHA256_DIGEST3 for DIGEST\\[127:96\\]
