@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<FIFOCFG_SPEC>> for R {
+impl From<crate::R<FIFOCFG_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<FIFOCFG_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<FIFOCFG_SPEC>> for W {
+impl From<crate::W<FIFOCFG_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<FIFOCFG_SPEC>) -> Self {
         W(writer)
     }
@@ -49,6 +51,7 @@ impl From<ENABLETX_A> for bool {
 #[doc = "Field `ENABLETX` reader - Enable the transmit FIFO."]
 pub struct ENABLETX_R(crate::FieldReader<bool, ENABLETX_A>);
 impl ENABLETX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ENABLETX_R(crate::FieldReader::new(bits))
     }
@@ -132,6 +135,7 @@ impl From<ENABLERX_A> for bool {
 #[doc = "Field `ENABLERX` reader - Enable the receive FIFO."]
 pub struct ENABLERX_R(crate::FieldReader<bool, ENABLERX_A>);
 impl ENABLERX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ENABLERX_R(crate::FieldReader::new(bits))
     }
@@ -215,6 +219,7 @@ impl From<TXI2SE0_A> for bool {
 #[doc = "Field `TXI2SE0` reader - Transmit I2S empty 0. Determines the value sent by the I2S in transmit mode if the TX FIFO becomes empty. This value is sent repeatedly until the I2S is paused, the error is cleared, new data is provided, and the I2S is un-paused."]
 pub struct TXI2SE0_R(crate::FieldReader<bool, TXI2SE0_A>);
 impl TXI2SE0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TXI2SE0_R(crate::FieldReader::new(bits))
     }
@@ -298,6 +303,7 @@ impl From<PACK48_A> for bool {
 #[doc = "Field `PACK48` reader - Packing format for 48-bit data. This relates to how data is entered into or taken from the FIFO by software or DMA."]
 pub struct PACK48_R(crate::FieldReader<bool, PACK48_A>);
 impl PACK48_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PACK48_R(crate::FieldReader::new(bits))
     }
@@ -367,6 +373,7 @@ impl<'a> PACK48_W<'a> {
 #[doc = "Field `SIZE` reader - FIFO size configuration. This is a read-only field. 0x0 = FIFO is configured as 16 entries of 8 bits. 0x1, 0x2, 0x3 = not applicable to USART."]
 pub struct SIZE_R(crate::FieldReader<u8, u8>);
 impl SIZE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SIZE_R(crate::FieldReader::new(bits))
     }
@@ -395,6 +402,7 @@ impl From<DMATX_A> for bool {
 #[doc = "Field `DMATX` reader - DMA configuration for transmit."]
 pub struct DMATX_R(crate::FieldReader<bool, DMATX_A>);
 impl DMATX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DMATX_R(crate::FieldReader::new(bits))
     }
@@ -478,6 +486,7 @@ impl From<DMARX_A> for bool {
 #[doc = "Field `DMARX` reader - DMA configuration for receive."]
 pub struct DMARX_R(crate::FieldReader<bool, DMARX_A>);
 impl DMARX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DMARX_R(crate::FieldReader::new(bits))
     }
@@ -561,6 +570,7 @@ impl From<WAKETX_A> for bool {
 #[doc = "Field `WAKETX` reader - Wake-up for transmit FIFO level. This allows the device to be woken from reduced power modes (up to power-down, as long as the peripheral function works in that power mode) without enabling the TXLVL interrupt. Only DMA wakes up, processes data, and goes back to sleep. The CPU will remain stopped until woken by another cause, such as DMA completion. See Hardware Wake-up control register."]
 pub struct WAKETX_R(crate::FieldReader<bool, WAKETX_A>);
 impl WAKETX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WAKETX_R(crate::FieldReader::new(bits))
     }
@@ -644,6 +654,7 @@ impl From<WAKERX_A> for bool {
 #[doc = "Field `WAKERX` reader - Wake-up for receive FIFO level. This allows the device to be woken from reduced power modes (up to power-down, as long as the peripheral function works in that power mode) without enabling the TXLVL interrupt. Only DMA wakes up, processes data, and goes back to sleep. The CPU will remain stopped until woken by another cause, such as DMA completion. See Hardware Wake-up control register."]
 pub struct WAKERX_R(crate::FieldReader<bool, WAKERX_A>);
 impl WAKERX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WAKERX_R(crate::FieldReader::new(bits))
     }
@@ -713,6 +724,7 @@ impl<'a> WAKERX_W<'a> {
 #[doc = "Field `EMPTYTX` reader - Empty command for the transmit FIFO. When a 1 is written to this bit, the TX FIFO is emptied."]
 pub struct EMPTYTX_R(crate::FieldReader<bool, bool>);
 impl EMPTYTX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EMPTYTX_R(crate::FieldReader::new(bits))
     }
@@ -749,6 +761,7 @@ impl<'a> EMPTYTX_W<'a> {
 #[doc = "Field `EMPTYRX` reader - Empty command for the receive FIFO. When a 1 is written to this bit, the RX FIFO is emptied."]
 pub struct EMPTYRX_R(crate::FieldReader<bool, bool>);
 impl EMPTYRX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EMPTYRX_R(crate::FieldReader::new(bits))
     }
@@ -891,6 +904,7 @@ impl W {
         EMPTYRX_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
