@@ -1,22 +1,22 @@
-#[doc = "Register `PIO0_5` reader"]
-pub struct R(crate::R<PIO0_5_SPEC>);
+#[doc = "Register `PIO0_27` reader"]
+pub struct R(crate::R<PIO0_27_SPEC>);
 impl core::ops::Deref for R {
-    type Target = crate::R<PIO0_5_SPEC>;
+    type Target = crate::R<PIO0_27_SPEC>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-impl From<crate::R<PIO0_5_SPEC>> for R {
+impl From<crate::R<PIO0_27_SPEC>> for R {
     #[inline(always)]
-    fn from(reader: crate::R<PIO0_5_SPEC>) -> Self {
+    fn from(reader: crate::R<PIO0_27_SPEC>) -> Self {
         R(reader)
     }
 }
-#[doc = "Register `PIO0_5` writer"]
-pub struct W(crate::W<PIO0_5_SPEC>);
+#[doc = "Register `PIO0_27` writer"]
+pub struct W(crate::W<PIO0_27_SPEC>);
 impl core::ops::Deref for W {
-    type Target = crate::W<PIO0_5_SPEC>;
+    type Target = crate::W<PIO0_27_SPEC>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -28,9 +28,9 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl From<crate::W<PIO0_5_SPEC>> for W {
+impl From<crate::W<PIO0_27_SPEC>> for W {
     #[inline(always)]
-    fn from(writer: crate::W<PIO0_5_SPEC>) -> Self {
+    fn from(writer: crate::W<PIO0_27_SPEC>) -> Self {
         W(writer)
     }
 }
@@ -188,7 +188,7 @@ impl<'a> FUNC_W<'a> {
         self.w
     }
 }
-#[doc = "Selects function mode (on-chip pull-up/pull-down resistor control).\n\nValue on reset: 2"]
+#[doc = "Selects function mode (on-chip pull-up/pull-down resistor control).\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
 pub enum MODE_A {
@@ -458,7 +458,7 @@ impl<'a> INVERT_W<'a> {
         self.w
     }
 }
-#[doc = "Select Digital mode.\n\nValue on reset: 1"]
+#[doc = "Select Digital mode.\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DIGIMODE_A {
     #[doc = "0: Disable digital mode. Digital input set to 0."]
@@ -696,23 +696,23 @@ impl W {
         self
     }
 }
-#[doc = "Digital I/O control for port 0 pins PIO0_5\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pio0_5](index.html) module"]
-pub struct PIO0_5_SPEC;
-impl crate::RegisterSpec for PIO0_5_SPEC {
+#[doc = "Digital I/O control for port 0 pins PIO0_27\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pio0_27](index.html) module"]
+pub struct PIO0_27_SPEC;
+impl crate::RegisterSpec for PIO0_27_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [pio0_5::R](R) reader structure"]
-impl crate::Readable for PIO0_5_SPEC {
+#[doc = "`read()` method returns [pio0_27::R](R) reader structure"]
+impl crate::Readable for PIO0_27_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [pio0_5::W](W) writer structure"]
-impl crate::Writable for PIO0_5_SPEC {
+#[doc = "`write(|w| ..)` method takes [pio0_27::W](W) writer structure"]
+impl crate::Writable for PIO0_27_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets PIO0_5 to value 0x0120"]
-impl crate::Resettable for PIO0_5_SPEC {
+#[doc = "`reset()` method sets PIO0_27 to value 0"]
+impl crate::Resettable for PIO0_27_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x0120
+        0
     }
 }
