@@ -1,12 +1,12 @@
 #[doc = r"Register block"]
 #[repr(C)]
 pub struct RegisterBlock {
-    #[doc = "0x00 - no description available"]
+    #[doc = "0x00..0x0c - no description available"]
     pub mboxirq0: MBOXIRQ,
-    _reserved1: [u8; 4usize],
-    #[doc = "0x10 - no description available"]
+    _reserved1: [u8; 0x04],
+    #[doc = "0x10..0x1c - no description available"]
     pub mboxirq1: MBOXIRQ,
-    _reserved2: [u8; 220usize],
+    _reserved2: [u8; 0xdc],
     #[doc = "0xf8 - Mutual exclusion register\\[1\\]"]
     pub mutex: crate::Reg<mutex::MUTEX_SPEC>,
 }
