@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<LUT_INP_MUX_SPEC>> for R {
+impl From<crate::R<LUT_INP_MUX_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<LUT_INP_MUX_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<LUT_INP_MUX_SPEC>> for W {
+impl From<crate::W<LUT_INP_MUX_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<LUT_INP_MUX_SPEC>) -> Self {
         W(writer)
     }
@@ -118,6 +120,7 @@ impl From<LUTN_INPX_A> for u8 {
 #[doc = "Field `LUTn_INPx` reader - Selects the input source to be connected to LUT0 input0. For each LUT, the slot associated with the output from LUTn itself is tied low."]
 pub struct LUTN_INPX_R(crate::FieldReader<u8, LUTN_INPX_A>);
 impl LUTN_INPX_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         LUTN_INPX_R(crate::FieldReader::new(bits))
     }
@@ -563,6 +566,7 @@ impl W {
         LUTN_INPX_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
