@@ -13,7 +13,7 @@ pub struct RegisterBlock {
     pub stop: crate::Reg<stop::STOP_SPEC>,
     #[doc = "0x14 - SCT start event select register"]
     pub start: crate::Reg<start::START_SPEC>,
-    _reserved6: [u8; 40usize],
+    _reserved6: [u8; 0x28],
     #[doc = "0x40 - SCT counter register"]
     pub count: crate::Reg<count::COUNT_SPEC>,
     #[doc = "0x44 - SCT state register"]
@@ -32,7 +32,7 @@ pub struct RegisterBlock {
     pub dmareq0: crate::Reg<dmareq0::DMAREQ0_SPEC>,
     #[doc = "0x60 - SCT DMA request 1 register"]
     pub dmareq1: crate::Reg<dmareq1::DMAREQ1_SPEC>,
-    _reserved15: [u8; 140usize],
+    _reserved15: [u8; 0x8c],
     #[doc = "0xf0 - SCT event interrupt enable register"]
     pub even: crate::Reg<even::EVEN_SPEC>,
     #[doc = "0xf4 - SCT event flag register"]
@@ -41,44 +41,44 @@ pub struct RegisterBlock {
     pub conen: crate::Reg<conen::CONEN_SPEC>,
     #[doc = "0xfc - SCT conflict flag register"]
     pub conflag: crate::Reg<conflag::CONFLAG_SPEC>,
-    _reserved_19_cap0: [u8; 4usize],
-    _reserved_20_cap1: [u8; 4usize],
-    _reserved_21_cap2: [u8; 4usize],
-    _reserved_22_cap3: [u8; 4usize],
-    _reserved_23_cap4: [u8; 4usize],
-    _reserved_24_cap5: [u8; 4usize],
-    _reserved_25_cap6: [u8; 4usize],
-    _reserved_26_cap7: [u8; 4usize],
-    _reserved_27_cap8: [u8; 4usize],
-    _reserved_28_cap9: [u8; 4usize],
-    _reserved_29_cap10: [u8; 4usize],
-    _reserved_30_cap11: [u8; 4usize],
-    _reserved_31_cap12: [u8; 4usize],
-    _reserved_32_cap13: [u8; 4usize],
-    _reserved_33_cap14: [u8; 4usize],
-    _reserved_34_cap15: [u8; 4usize],
-    _reserved35: [u8; 192usize],
-    _reserved_35_capctrl0: [u8; 4usize],
-    _reserved_36_capctrl1: [u8; 4usize],
-    _reserved_37_capctrl2: [u8; 4usize],
-    _reserved_38_capctrl3: [u8; 4usize],
-    _reserved_39_capctrl4: [u8; 4usize],
-    _reserved_40_capctrl5: [u8; 4usize],
-    _reserved_41_capctrl6: [u8; 4usize],
-    _reserved_42_capctrl7: [u8; 4usize],
-    _reserved_43_capctrl8: [u8; 4usize],
-    _reserved_44_capctrl9: [u8; 4usize],
-    _reserved_45_capctrl10: [u8; 4usize],
-    _reserved_46_capctrl11: [u8; 4usize],
-    _reserved_47_capctrl12: [u8; 4usize],
-    _reserved_48_capctrl13: [u8; 4usize],
-    _reserved_49_capctrl14: [u8; 4usize],
-    _reserved_50_capctrl15: [u8; 4usize],
-    _reserved51: [u8; 192usize],
-    #[doc = "0x300 - no description available"]
+    _reserved_19_cap0: [u8; 0x04],
+    _reserved_20_cap1: [u8; 0x04],
+    _reserved_21_cap2: [u8; 0x04],
+    _reserved_22_cap3: [u8; 0x04],
+    _reserved_23_cap4: [u8; 0x04],
+    _reserved_24_cap5: [u8; 0x04],
+    _reserved_25_cap6: [u8; 0x04],
+    _reserved_26_cap7: [u8; 0x04],
+    _reserved_27_cap8: [u8; 0x04],
+    _reserved_28_cap9: [u8; 0x04],
+    _reserved_29_cap10: [u8; 0x04],
+    _reserved_30_cap11: [u8; 0x04],
+    _reserved_31_cap12: [u8; 0x04],
+    _reserved_32_cap13: [u8; 0x04],
+    _reserved_33_cap14: [u8; 0x04],
+    _reserved_34_cap15: [u8; 0x04],
+    _reserved35: [u8; 0xc0],
+    _reserved_35_capctrl0: [u8; 0x04],
+    _reserved_36_capctrl1: [u8; 0x04],
+    _reserved_37_capctrl2: [u8; 0x04],
+    _reserved_38_capctrl3: [u8; 0x04],
+    _reserved_39_capctrl4: [u8; 0x04],
+    _reserved_40_capctrl5: [u8; 0x04],
+    _reserved_41_capctrl6: [u8; 0x04],
+    _reserved_42_capctrl7: [u8; 0x04],
+    _reserved_43_capctrl8: [u8; 0x04],
+    _reserved_44_capctrl9: [u8; 0x04],
+    _reserved_45_capctrl10: [u8; 0x04],
+    _reserved_46_capctrl11: [u8; 0x04],
+    _reserved_47_capctrl12: [u8; 0x04],
+    _reserved_48_capctrl13: [u8; 0x04],
+    _reserved_49_capctrl14: [u8; 0x04],
+    _reserved_50_capctrl15: [u8; 0x04],
+    _reserved51: [u8; 0xc0],
+    #[doc = "0x300..0x380 - no description available"]
     pub ev: [EV; 16],
-    _reserved52: [u8; 384usize],
-    #[doc = "0x500 - no description available"]
+    _reserved52: [u8; 0x0180],
+    #[doc = "0x500..0x550 - no description available"]
     pub out: [OUT; 10],
 }
 impl RegisterBlock {
